# arcgis-compressed-geometry

A Python library for encoding and decoding ArcGIS Compressed Geometry Format.

## Introduction

This library provides encoding and decoding functionality for ArcGIS Compressed Geometry Format. It supports the following coordinate formats:

- xy (2D coordinates)
- xyz (3D coordinates with elevation)
- xym (coordinates with measure values)
- xyzm (coordinates with elevation and measure values)

## Installation
